/*
    This file is a part of Musty, a simple Molecular Dynamics simulation
    package.
    
    Copyright (C) 2005 Jori Liesenborgs

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef CONSTANTS_H

#define CONSTANTS_H

#include "realtype.h"

#ifndef LONGREAL

#define MASS_SOLAR					(1.9891e30)
#define DIST_PC						(3.085678e13)
#define DIST_KPC					(1000.0*DIST_PC)
#define DIST_MPC					(1000.0*DIST_KPC)
#define DIST_GPC					(1000.0*DIST_MPC)
#define SPEED_C						(299792458.0)
#define CONST_G						(6.67300e-11)
#define CONST_PI					(3.14159265)
#define ANGLE_DEGREE					(CONST_PI/180.0)
#define ANGLE_ARCMIN					(ANGLE_DEGREE/60.0)
#define ANGLE_ARCSEC					(ANGLE_ARCMIN/60.0)
#define ANGLE_MILLIARCSEC				(ANGLE_ARCSEC/1000.0)
#define ANGLE_MICROARCSEC				(ANGLE_MILLIARCSEC/1000.0)

#else

#define MASS_SOLAR					(1.9891e30L)
#define DIST_PC						(3.085678e13L)
#define DIST_KPC					(1000.0L*DIST_PC)
#define DIST_MPC					(1000.0L*DIST_KPC)
#define DIST_GPC					(1000.0L*DIST_MPC)
#define SPEED_C						(299792458.0L)
#define CONST_G						(6.67300e-11L)
#define CONST_PI					(3.14159265L)
#define ANGLE_DEGREE					(CONST_PI/180.0L)
#define ANGLE_ARCMIN					(ANGLE_DEGREE/60.0L)
#define ANGLE_ARCSEC					(ANGLE_ARCMIN/60.0L)
#define ANGLE_MILLIARCSEC				(ANGLE_ARCSEC/1000.0L)
#define ANGLE_MICROARCSEC				(ANGLE_MILLIARCSEC/1000.0L)

#endif // LONGREAL

#endif // CONSTANTS_H

