/*
    This file is a part of Musty, a simple Molecular Dynamics simulation
    package.
    
    Copyright (C) 2005 Jori Liesenborgs

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef VECTOR3D_H

#define VECTOR3D_H

#include "realtype.h"

class Vector3D
{
public:
	Vector3D()									{ vx = 0; vy = 0; vz = 0; }
	Vector3D(real_t x,real_t y,real_t z)						{ vx = x; vy = y; vz = z; }
	real_t GetX() const								{ return vx; }
	real_t GetY() const								{ return vy; }
	real_t GetZ() const								{ return vz; }
	real_t GetLength() const							{ return SQRT(vx*vx+vy*vy+vz*vz); }
	real_t GetLength2() const							{ return vx*vx+vy*vy+vz*vz; }
	real_t GetComponent(int i) const						{ if (i == 1) return vx; if (i == 2) return vy; return vz; }
	Vector3D &operator+=(const Vector3D v)						{ vx += v.vx; vy += v.vy; vz += v.vz; return *this; }
	Vector3D &operator-=(const Vector3D v)						{ vx -= v.vx; vy -= v.vy; vz -= v.vz; return *this; }
	Vector3D &operator*=(real_t a)							{ vx *= a; vy *= a; vz *= a; return *this; }
	Vector3D &operator/=(real_t a)							{ vx /= a; vy /= a; vz /= a; return *this; }
private:
	real_t vx,vy,vz;
};

inline Vector3D operator+(Vector3D v1,Vector3D v2)
{
	return Vector3D(v1.GetX()+v2.GetX(),v1.GetY()+v2.GetY(),v1.GetZ()+v2.GetZ());
}

inline Vector3D operator-(Vector3D v1,Vector3D v2)
{
	return Vector3D(v1.GetX()-v2.GetX(),v1.GetY()-v2.GetY(),v1.GetZ()-v2.GetZ());
}

inline Vector3D operator*(Vector3D v,real_t m)
{
	return Vector3D(v.GetX()*m,v.GetY()*m,v.GetZ()*m);
}

inline Vector3D operator*(real_t m,Vector3D v)
{
	return Vector3D(v.GetX()*m,v.GetY()*m,v.GetZ()*m);
}

inline Vector3D operator/(Vector3D v,real_t d)
{
	return Vector3D(v.GetX()/d,v.GetY()/d,v.GetZ()/d);
}

inline real_t operator*(Vector3D v1,Vector3D v2)
{
	return v1.GetX()*v2.GetX()+v1.GetY()*v2.GetY()+v1.GetZ()*v2.GetZ();
}

#endif // VECTOR3D_H

